#[non_exhaustive]pub enum FormatError {
InsufficientParameters,
InvalidFormatString,
UnsupportedFormatType,
ExpectedUsize,
WriteFailed,
}Expand description
Error returned by Format::try_format.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InsufficientParameters
A placeholder index is beyond the number of supplied arguments.
InvalidFormatString
The template is syntactically invalid (unbalanced braces, named arguments, an illegal spec, …).
UnsupportedFormatType
The argument does not support the requested format type (e.g. {:x}
on a string, or the unsupported {:p}).
ExpectedUsize
The argument referenced by {:1$} / {:.1$} as a width/precision is
not an unsigned integer.
WriteFailed
The output sink rejected a write (fmt::Write::write_str returned
Err). Writing into a String never fails.